@@ -28,9 +28,9 @@ from socket		import gethostname
 from collections  import OrderedDict
 from datetime     import datetime
 from importlib    import import_module
-# from IPython	import embed
+from IPython	import embed
 
-__version__    = '0.1.3'
+__version__    = '0.2.0'
 
 cc = jt.cc()
 
@@ -239,9 +239,15 @@ def load_routine(name, cfg=None, show_trace=False):
 	if nlevels == 1:
 		if type(__builtins__).__name__ == 'dict': routine = __builtins__[levels[0]]
 		else:							routine = getattr(__builtins__, levels[0])
-		if show_trace: print(cc.key + 'loading', routine, type(routine).__name__, cc.reset)
+		if show_trace: print(cc.key + 'loading:', routine, type(routine).__name__, cc.reset)
 		return routine, None
 
+	# this shouldn't be necessary, but since I don't understand something, here it is
+	# if levels[0] == 'clise':
+	# 	levels = levels[1:]
+	# 	levels[0] = 'clise.' + levels[0]
+	# 	nlevels = nlevels - 1
+
 	if levels[0] not in sys.modules:
 		module = __import__(levels[0])
 	else:
@@ -249,29 +255,44 @@ def load_routine(name, cfg=None, show_trace=False):
 
 	# potential class name
 	class_name_ = '.'.join(levels[0:-1])
-	global class_object, class_name
+	global class_obj, class_name
 	if "-object" in cfg:
 		if cfg["-object"] in class_obj:
-			if show_trace: print('loading the requested object', cc.key, cfg["-object"], cc.reset)
+			if show_trace: print(cc.key + 'loading the requested object:', cfg["-object"], cc.reset)
 			object = class_obj[cfg["-object"]]
 			routine = getattr(object, levels[-1])
 			return routine, module
 	else:
 		if class_name_ in class_obj:
-			if show_trace: print('loading the existing object', cc.key, class_name_, cc.reset)
+			if show_trace: print(cc.key + 'loading the existing object:', class_name_, cc.reset)
 			object = class_obj[class_name_]
 			routine = getattr(object, levels[-1])
 			return routine, module
 
 	routine = module
-	if show_trace: print(cc.key + 'loading', routine, type(routine).__name__, cc.reset)
+	if show_trace: print(cc.key + 'loading:', routine, type(routine).__name__, cc.reset)
 	for idx, each in enumerate(levels[1:]):
+
+		#  this shouldn't be necessary, but since I don't understand something, here it is
+		#  or this must be a more generic issue, requiring a better solution
+		#  i.e., why does it load "each" from "routine"? instead, it ignores "routine",
+		#  and look just for "each"
+		if idx == 0 and routine.__name__ == 'clise':
+			routine = import_module('clise.' + each)
+			if show_trace:
+				print(cc.key + 'loading:', idx, routine, type(routine).__name__, cc.reset)
+
+			continue
+
 		try:
 			routine = getattr(routine, each)
+			# if show_trace: print(cc.key + 'loading got attr', cc.reset)
+
 		except AttributeError:
 			routine = import_module(each, routine)
+			# if show_trace: print(cc.key + 'loading a module', each, cc.reset)
 
-		if show_trace: print(cc.key + 'loading', idx, routine, type(routine).__name__, cc.reset)
+		if show_trace: print(cc.key + 'loading:', idx, routine, type(routine).__name__, cc.reset)
 
 		if idx == nlevels - 3:  # -3 indicates the next to the last name
 
@@ -280,7 +301,8 @@ def load_routine(name, cfg=None, show_trace=False):
 			init_args, init_kwargs = set_func_parameters([], [], cfg=icfg)
 
 			# print(init_args, init_kwargs)
-			try:
+			# try:
+			if type(routine).__name__ == 'type':
 				# now we are loading a new class or attempting
 
 				class_obj_  = routine(*init_args, **init_kwargs)
@@ -295,7 +317,10 @@ def load_routine(name, cfg=None, show_trace=False):
 				# if you are here, then safe to assign these
 				class_name[objkey] = class_name_
 				class_obj [objkey] = class_obj_
-			except Exception:
+			# except Exception:
+			else:
+				# an issue with "try: .. except:" is if exception occurs due to an error in a class
+				# one ends up here as well, which will fail
 				# oops, not class
 				routine = getattr(routine, levels[-1])
 			break
