@@ -269,7 +269,8 @@ def substitute_local(inp, pre=None, post='}', level=0):
 	"""
 
 	if pre is None:
-		if   level == -1: pre = '{<'
+		if   level == -2: pre = '{<<'
+		elif level == -1: pre = '{<'
 		elif level == 0:  pre = '{'
 		elif level == 1:  pre = '{>'
 		else:		      pre = '{>>'
@@ -725,6 +726,10 @@ def process_cfg(cfg, level=0, ignore_main=False):
 	# substitution?
 	cfg = substitute_local(cfg, level=level)
 
+	# '{<<parameter}' can be substituted by the command line options later
+	# this requires a caution when used with a loop 
+	cfg = substitute_local(cfg, level=-2) 
+
 	# order 8
 	# enforce numeric parameter from cmdline or json file
 	# -#key "12.34" => "key": 12.34
@@ -1241,7 +1246,10 @@ def load_cli(cli=sys.argv[1:]):
 							for each in apply:
 								if each in share_: del share_[each]
 							task = merge_before(task, share_)
+							# from IPython import embed; embed()
+							# if not after.get('-holdsub', False):
 							task = substitute_local(task, level=-1)
+							# from IPython import embed; embed()
 
 					# this is a regular routine
 					id = task.get('-id', '')
