@@ -226,7 +226,7 @@ def pick(infile, indir=None, include=None, exclude=None, verbose=0):
 # iteration loop settings
 def search_infile(infile_expre, tagid='', indir=None,
 		include=None, exclude=None,
-		recursive_search=True, sortby='',
+		recursive_search=True, sortby='', onlylist=False,
 		verbose=0):
 	""" make file list from wild card input file parameters
 	"""
@@ -278,6 +278,7 @@ def search_infile(infile_expre, tagid='', indir=None,
 
 	# now actual file search for each searchable file expression
 	ans = OrderedDict()
+	names = []
 	for id, cfile in canfiles.items():
 
 		if cfile['schfile'] == '': continue
@@ -290,6 +291,8 @@ def search_infile(infile_expre, tagid='', indir=None,
 
 		if len(files) == 0: continue
 
+		files.sort(key=lambda x:[int(c) if c.isdigit() else c for c in re.split(r'(\d+)', x)])
+
 		# check if the found match with the original regular expression
 		if cfile['isregex']:
 			survived = []
@@ -320,9 +323,11 @@ def search_infile(infile_expre, tagid='', indir=None,
 			key = file + ' ' + str(id)
 			# unique key is determined by the filename and group id
 			ans[key] = x
+			names.append(file)
 
 	chdir(cdir)
 
+	if onlylist: return names
 	return ans
 
 def get_outfile(outfile, infile, outdir=None, outsubdir=None,
@@ -694,13 +699,13 @@ def multiply_by_file(seed, inkey="infile", outkey=None,
 
 		if outkey in seed:
 			outfile = seed.get(outkey, None)
-			print('====', outdir, outfile)
-			outfile, outdir = get_outfile(outfile, name,
+			# print('====', outdir, outfile)
+			outfile, outdir_ = get_outfile(outfile, name,
 						outdir=outdir, outsubdir=outsubdir,
 						mirror_indir=mirror_indir, switch_subdir=switch_subdir,
 						tags=tag, cfg=seed, verbose=verbose)
 			task[outkey] = Path(outfile).expanduser()
-			print('====', outdir, outfile)
+			# print('====', outdir, outfile)
 
 		# expand ~***
 		if indir is not None: task[inkey] = (Path(indir) / Path(name)).expanduser()
@@ -763,6 +768,8 @@ def multiply_by_file(seed, inkey="infile", outkey=None,
 			task['-checkout'] = task['-checkout'] + checkout
 
 		tasks.append(task)
+		# from IPython	import embed
+		# embed()
 
 	# here we have to sort when we have both infile and outfile
 	if before is not None:
@@ -883,7 +890,7 @@ def multiply_by_file_multi(seed, cases=None, inkey="infile", outkey="outfile",
 
 			if outkey in eseed:
 				outfile = eseed[outkey]
-				outfile, outdir = get_outfile(outfile, name,
+				outfile, outdir_ = get_outfile(outfile, name,
 							outdir=outdir, outsubdir=outsubdir,
 							mirror_indir=mirror_indir, switch_subdir=switch_subdir,
 							tags=tag, cfg=eseed, verbose=verbose)
