@@ -154,14 +154,31 @@ def to_csv_or_fits(filename, table, overwrite=True, index=False, allstring=False
 	elif bool(re.search(r'\.fits(|\.gz)$', basename)):
 		to_fits(filename, table, overwrite=overwrite, allstring=allstring)
 
+def read_mca(filename, columns=None):
+	if columns is None: columns = ['data']
+	with open(filename, encoding='utf-8', errors='ignore') as f:
+		lines = f.readlines()
+
+	data = []
+	start = False
+	for line in lines:
+		if bool(re.search(r'<<END>>',  line)): break
+		if start:
+			data.append(int(line))
+		if bool(re.search(r'<<DATA>>', line)): start = True
+
+	return pd.DataFrame(data, columns=columns)
+
 # read the table from a csv or fits file or a few other formats
-def from_csv_or_fits(filename, index=False, ftype=None, hdu=1, nopandas=False, fill=-1):
+def from_csv_or_fits(filename, index=False, ftype=None, hdu=1, nopandas=False, fill=-1, columns=None, comment=None):
 	filename = str(Path(filename).expanduser())
 	basename = path.basename(filename)
 
 	if ftype is not None:
 		if   ftype == "json": return pd.read_json(filename)
-		elif ftype == "csv" : return pd.read_csv (filename, index_col=index)
+		elif ftype == "csv" : return pd.read_csv (filename, index_col=index, comment=None)
+		elif ftype == "mca" : return read_mca (filename, columns=columns)
+		# elif ftype == "tiff": return read_img (filename)
 		elif ftype == "fits": return ast_to_pd(Table.read(filename, format='fits', hdu=hdu), nopandas)
 		elif ftype == "fitshdr": return fits.open(filename)[hdu].header
 		else:
@@ -170,7 +187,9 @@ def from_csv_or_fits(filename, index=False, ftype=None, hdu=1, nopandas=False, f
 
 	if   bool(re.search(r'\.fits(|\.gz)$', basename)): return ast_to_pd(Table.read(filename, format='fits', hdu=hdu), nopandas)
 	elif bool(re.search( r'\.mrt(|\.gz)$', basename)): return ast_to_pd(Table.read(filename, format='ascii.mrt'),     nopandas)
-	elif bool(re.search( r'\.csv(|\.gz)$', basename)): return pd.read_csv (filename, index_col=index)
+	elif bool(re.search( r'\.csv(|\.gz)$', basename)): return pd.read_csv (filename, index_col=index, comment=comment)
+	elif bool(re.search( r'\.mca(|\.gz)$', basename)): return read_mca    (filename, columns=columns)
+	# elif bool(re.search(r'\.tiff(|\.gz)$', basename)): return read_img    (filename)
 	elif bool(re.search( r'\.xml(|\.gz)$', basename)): return pd.read_xml (filename)
 	elif bool(re.search(r'\.json(|\.gz)$', basename)): return pd.read_json(filename)
 
