@@ -886,19 +886,53 @@ class xray_mirror:
 		plt.clf()
 		plt.close("all")
 
-	# this is getting too many input parameters....
-	def get_EA_from_SDD(infile, bkgfile, mdlfile=None, winfile=None,
-				ctsplot=None, EAplot=None, EAdata=None,
-				xr_cts=None, yr_cts=None, xlog_cts=None, ylog_cts=None,
-				xr_EA=None, yr_EA=None, xlog_EA=None, ylog_EA=None,
-				srccolorfull="red",   srclabelfull="Source",
-				srccoloraper="organge", srclabelaper="Source 1am", aperexpr=None,
-				bkgcolor="black", bkglabel="Beam"):
+# this is getting too many input parameters....
+def get_EA_from_line(srcfile, bkgfile,
+	out='csv',
+	xr=None,
+	ch2e=None,  # channel to energy conversion
+	c4ea=1.0,   # conversion to effective area
+	id="", idhdr='id',
+	verbose=0, hold=False):
+
+	src = tt.from_csv_or_fits(srcfile)
+	bkg = tt.from_csv_or_fits(bkgfile)
+
+	if xr is None: xr = [0, len(src) - 1]
+	if ch2e is not None:
+		xr[0] = round(xr[0] / ch2e)
+		xr[1] = round(xr[1] / ch2e)
+
+	srctot = float(np.sum(src[xr[0]:xr[1]]))
+	bkgtot = float(np.sum(bkg[xr[0]:xr[1]]))
+
+	err_srctot = np.sqrt(srctot)
+	err_bkgtot = np.sqrt(bkgtot)
+
+	EA = float(srctot / bkgtot * c4ea)
+	err_EA = EA * np.sqrt((err_srctot / srctot)**2 + (err_bkgtot / bkgtot)**2)
+
+	if out == 'csv':
+		if verbose > 0:
+			for each in ['EA', 'err_EA', 'src', 'bkg', 'ch2e', 'c4ea', 'xlow', 'xhigh']:
+				print(each, end=',')
+			print(idhdr)
+		for each in [EA, err_EA, srctot, bkgtot, ch2e, c4ea, xr[0], xr[1]]:
+			print(each, end=',')
+		print(id)
+	else:
+		if verbose > 1:
+			print('channel->energy:', ch2e, 'conversion 4 EA:', c4ea)
+			print('xr:', xr)
+			print('src:', srctot, 'bkgtot:', bkgtot)
+		if verbose > 0:
+			print('srcfile:', srcfile)
+		print('id', id)
+		print('EA:', EA, '+/-', err_EA)
+
+	if hold: pt.embed()
+
 
-		ea = pt.plottool()
-		ea.collect_data(infile=bkgfile, key="beam",     label=bkglabel,     color=bkgcolor)
-		ea.collect_data(infile=infile,  key="src full", label=srclabelfull, color=srccolorfull)
-		ea.collect_data(infile=infile,  key="src aper", label=srclabelaper, color=srccoloraper, yexpr=aperexpr)
 
 # ---------------------------------------------------------------------------
 # SAORT output summary
